@@ -791,6 +791,7 @@ class FuzzyPSO(PSO_new):
 
 
 	def call_fitness(self, particle, arguments=None):
+		
 		if self.FITNESS == None: raise Exception("ERROR: fitness function not valid")
 
 		data = particle.X
@@ -975,8 +976,15 @@ class FuzzyPSO(PSO_new):
 
 		# parallel evaluation
 		if self.ParallelFitness:
-			if self._discrete_cases is not None: raise NotImplementedError() # TODO
+
 			ripop = list(map(lambda x: x.X, self.Solutions))
+
+			if self._discrete_cases is not None: 
+
+				ripop = [self._convert_prob_to_particle(data) for data in ripop]
+				for particle, instance in zip(self.Solutions, ripop):
+					particle._last_discrete_sample = instance
+
 			# TODO: make parallel version of discrete case
 			if self._FITNESS_ARGS is not None:
 				all_fitness = self.FITNESS(ripop, self._FITNESS_ARGS)
